import { JwtError } from "./jwt/error";
import { FirebaseTokenInfo } from "./firebase";
export declare class FirebaseError extends Error {
    private errorInfo;
    constructor(errorInfo: ErrorInfo);
    get code(): string;
    get message(): string;
    toJSON(): object;
}
export interface ErrorInfo {
    code: string;
    message: string;
}
export declare class PrefixedFirebaseError extends FirebaseError {
    private prefix;
    constructor(prefix: string, code: string, message: string);
    hasCode(code: string): boolean;
}
export declare class FirebaseAuthError extends PrefixedFirebaseError {
    static fromServerError(serverErrorCode: string, message?: string, rawServerResponse?: object): FirebaseAuthError;
    constructor(info: ErrorInfo, message?: string);
    static toAuthErrorWithStack(code: ErrorInfo, message: string, jwtError: JwtError): FirebaseAuthError;
    static fromJwtError(error: JwtError, tokenInfo: FirebaseTokenInfo, shortNameArticle: string): FirebaseAuthError;
}
export declare class AuthClientErrorCode {
    static AUTH_BLOCKING_TOKEN_EXPIRED: {
        code: string;
        message: string;
    };
    static BILLING_NOT_ENABLED: {
        code: string;
        message: string;
    };
    static CLAIMS_TOO_LARGE: {
        code: string;
        message: string;
    };
    static CONFIGURATION_EXISTS: {
        code: string;
        message: string;
    };
    static CONFIGURATION_NOT_FOUND: {
        code: string;
        message: string;
    };
    static ID_TOKEN_EXPIRED: {
        code: string;
        message: string;
    };
    static INVALID_ARGUMENT: {
        code: string;
        message: string;
    };
    static INVALID_CONFIG: {
        code: string;
        message: string;
    };
    static EMAIL_ALREADY_EXISTS: {
        code: string;
        message: string;
    };
    static EMAIL_NOT_FOUND: {
        code: string;
        message: string;
    };
    static FORBIDDEN_CLAIM: {
        code: string;
        message: string;
    };
    static INVALID_ID_TOKEN: {
        code: string;
        message: string;
    };
    static ID_TOKEN_REVOKED: {
        code: string;
        message: string;
    };
    static INTERNAL_ERROR: {
        code: string;
        message: string;
    };
    static INVALID_CLAIMS: {
        code: string;
        message: string;
    };
    static INVALID_CONTINUE_URI: {
        code: string;
        message: string;
    };
    static INVALID_CREATION_TIME: {
        code: string;
        message: string;
    };
    static INVALID_CREDENTIAL: {
        code: string;
        message: string;
    };
    static INVALID_DISABLED_FIELD: {
        code: string;
        message: string;
    };
    static INVALID_DISPLAY_NAME: {
        code: string;
        message: string;
    };
    static INVALID_DYNAMIC_LINK_DOMAIN: {
        code: string;
        message: string;
    };
    static INVALID_EMAIL_VERIFIED: {
        code: string;
        message: string;
    };
    static INVALID_EMAIL: {
        code: string;
        message: string;
    };
    static INVALID_NEW_EMAIL: {
        code: string;
        message: string;
    };
    static INVALID_ENROLLED_FACTORS: {
        code: string;
        message: string;
    };
    static INVALID_ENROLLMENT_TIME: {
        code: string;
        message: string;
    };
    static INVALID_HASH_ALGORITHM: {
        code: string;
        message: string;
    };
    static INVALID_HASH_BLOCK_SIZE: {
        code: string;
        message: string;
    };
    static INVALID_HASH_DERIVED_KEY_LENGTH: {
        code: string;
        message: string;
    };
    static INVALID_HASH_KEY: {
        code: string;
        message: string;
    };
    static INVALID_HASH_MEMORY_COST: {
        code: string;
        message: string;
    };
    static INVALID_HASH_PARALLELIZATION: {
        code: string;
        message: string;
    };
    static INVALID_HASH_ROUNDS: {
        code: string;
        message: string;
    };
    static INVALID_HASH_SALT_SEPARATOR: {
        code: string;
        message: string;
    };
    static INVALID_LAST_SIGN_IN_TIME: {
        code: string;
        message: string;
    };
    static INVALID_NAME: {
        code: string;
        message: string;
    };
    static INVALID_OAUTH_CLIENT_ID: {
        code: string;
        message: string;
    };
    static INVALID_PAGE_TOKEN: {
        code: string;
        message: string;
    };
    static INVALID_PASSWORD: {
        code: string;
        message: string;
    };
    static INVALID_PASSWORD_HASH: {
        code: string;
        message: string;
    };
    static INVALID_PASSWORD_SALT: {
        code: string;
        message: string;
    };
    static INVALID_PHONE_NUMBER: {
        code: string;
        message: string;
    };
    static INVALID_PHOTO_URL: {
        code: string;
        message: string;
    };
    static INVALID_PROJECT_ID: {
        code: string;
        message: string;
    };
    static INVALID_PROVIDER_DATA: {
        code: string;
        message: string;
    };
    static INVALID_PROVIDER_ID: {
        code: string;
        message: string;
    };
    static INVALID_PROVIDER_UID: {
        code: string;
        message: string;
    };
    static INVALID_OAUTH_RESPONSETYPE: {
        code: string;
        message: string;
    };
    static INVALID_SESSION_COOKIE_DURATION: {
        code: string;
        message: string;
    };
    static INVALID_TENANT_ID: {
        code: string;
        message: string;
    };
    static INVALID_TENANT_TYPE: {
        code: string;
        message: string;
    };
    static INVALID_TESTING_PHONE_NUMBER: {
        code: string;
        message: string;
    };
    static INVALID_UID: {
        code: string;
        message: string;
    };
    static INVALID_USER_IMPORT: {
        code: string;
        message: string;
    };
    static INVALID_TOKENS_VALID_AFTER_TIME: {
        code: string;
        message: string;
    };
    static MISMATCHING_TENANT_ID: {
        code: string;
        message: string;
    };
    static MISSING_ANDROID_PACKAGE_NAME: {
        code: string;
        message: string;
    };
    static MISSING_CONFIG: {
        code: string;
        message: string;
    };
    static MISSING_CONTINUE_URI: {
        code: string;
        message: string;
    };
    static MISSING_DISPLAY_NAME: {
        code: string;
        message: string;
    };
    static MISSING_EMAIL: {
        code: string;
        message: string;
    };
    static MISSING_IOS_BUNDLE_ID: {
        code: string;
        message: string;
    };
    static MISSING_ISSUER: {
        code: string;
        message: string;
    };
    static MISSING_HASH_ALGORITHM: {
        code: string;
        message: string;
    };
    static MISSING_OAUTH_CLIENT_ID: {
        code: string;
        message: string;
    };
    static MISSING_OAUTH_CLIENT_SECRET: {
        code: string;
        message: string;
    };
    static MISSING_PROVIDER_ID: {
        code: string;
        message: string;
    };
    static MISSING_SAML_RELYING_PARTY_CONFIG: {
        code: string;
        message: string;
    };
    static MAXIMUM_TEST_PHONE_NUMBER_EXCEEDED: {
        code: string;
        message: string;
    };
    static MAXIMUM_USER_COUNT_EXCEEDED: {
        code: string;
        message: string;
    };
    static MISSING_UID: {
        code: string;
        message: string;
    };
    static OPERATION_NOT_ALLOWED: {
        code: string;
        message: string;
    };
    static PHONE_NUMBER_ALREADY_EXISTS: {
        code: string;
        message: string;
    };
    static PROJECT_NOT_FOUND: {
        code: string;
        message: string;
    };
    static INSUFFICIENT_PERMISSION: {
        code: string;
        message: string;
    };
    static QUOTA_EXCEEDED: {
        code: string;
        message: string;
    };
    static SECOND_FACTOR_LIMIT_EXCEEDED: {
        code: string;
        message: string;
    };
    static SECOND_FACTOR_UID_ALREADY_EXISTS: {
        code: string;
        message: string;
    };
    static SESSION_COOKIE_EXPIRED: {
        code: string;
        message: string;
    };
    static SESSION_COOKIE_REVOKED: {
        code: string;
        message: string;
    };
    static TENANT_NOT_FOUND: {
        code: string;
        message: string;
    };
    static UID_ALREADY_EXISTS: {
        code: string;
        message: string;
    };
    static UNAUTHORIZED_DOMAIN: {
        code: string;
        message: string;
    };
    static UNSUPPORTED_FIRST_FACTOR: {
        code: string;
        message: string;
    };
    static UNSUPPORTED_SECOND_FACTOR: {
        code: string;
        message: string;
    };
    static UNSUPPORTED_TENANT_OPERATION: {
        code: string;
        message: string;
    };
    static UNVERIFIED_EMAIL: {
        code: string;
        message: string;
    };
    static USER_NOT_FOUND: {
        code: string;
        message: string;
    };
    static NOT_FOUND: {
        code: string;
        message: string;
    };
    static USER_DISABLED: {
        code: string;
        message: string;
    };
    static USER_NOT_DISABLED: {
        code: string;
        message: string;
    };
}
